==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/record/bean/RecordquotasummarydetaillEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计汇总变更记录子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_quotasummarydetaill")
public class RecordquotasummarydetaillEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_mid")
    private java.lang.Long recordMid; // 限额设计汇总变更记录主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="unit_project_name")
    private java.lang.String unitProjectName; // 单位工程名称
    @TableField(value="project_cost")
    private java.math.BigDecimal projectCost; // 项目造价
    @TableField(value="labor_cost")
    private java.math.BigDecimal laborCost; // 人工费
    @TableField(value="material_cost")
    private java.math.BigDecimal materialCost; // 材料费
    @TableField(value="mechanical_cost")
    private java.math.BigDecimal mechanicalCost; // 机械费
    @TableField(value="management_cost")
    private java.math.BigDecimal managementCost; // 企业管理费
    @TableField(value="profit")
    private java.math.BigDecimal profit; // 利润
    @TableField(value="partial_item_total")
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    @TableField(value="among_thenl")
    private java.math.BigDecimal amongThenl; // 其中:施工垃圾场外晕和消纳费
    @TableField(value="measures_total")
    private java.math.BigDecimal measuresTotal; // 单方措施项目合计
    @TableField(value="other_items")
    private java.math.BigDecimal otherItems; // 其他项目
    @TableField(value="fees")
    private java.math.BigDecimal fees; // 规费
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="cost_ration")
    private java.math.BigDecimal costRation; // 占造价比例(%)(仅包括分部分项和单价措施)
    @TableField(value="scale")
    private java.math.BigDecimal scale; // 工程规模(m²或m)
    @TableField(value="unit_cost")
    private java.math.BigDecimal unitCost; // 单位造价(元/m²或元/m)
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    
    
    

    /**
     * 限额设计汇总变更记录主表id
     */
    public java.lang.Long getRecordMid() {
        return recordMid;
    }

    /**
     * 限额设计汇总变更记录主表id
     */
    public void setRecordMid(java.lang.Long recordMid) {
        this.recordMid = recordMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 单位工程名称
     */
    public java.lang.String getUnitProjectName() {
        return unitProjectName;
    }

    /**
     * 单位工程名称
     */
    public void setUnitProjectName(java.lang.String unitProjectName) {
        this.unitProjectName = unitProjectName;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalCost() {
        return mechanicalCost;
    }

    /**
     * 机械费
     */
    public void setMechanicalCost(java.math.BigDecimal mechanicalCost) {
        this.mechanicalCost = mechanicalCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getManagementCost() {
        return managementCost;
    }

    /**
     * 企业管理费
     */
    public void setManagementCost(java.math.BigDecimal managementCost) {
        this.managementCost = managementCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其中:施工垃圾场外晕和消纳费
     */
    public java.math.BigDecimal getAmongThenl() {
        return amongThenl;
    }

    /**
     * 其中:施工垃圾场外晕和消纳费
     */
    public void setAmongThenl(java.math.BigDecimal amongThenl) {
        this.amongThenl = amongThenl;
    }
    /**
     * 单方措施项目合计
     */
    public java.math.BigDecimal getMeasuresTotal() {
        return measuresTotal;
    }

    /**
     * 单方措施项目合计
     */
    public void setMeasuresTotal(java.math.BigDecimal measuresTotal) {
        this.measuresTotal = measuresTotal;
    }
    /**
     * 其他项目
     */
    public java.math.BigDecimal getOtherItems() {
        return otherItems;
    }

    /**
     * 其他项目
     */
    public void setOtherItems(java.math.BigDecimal otherItems) {
        this.otherItems = otherItems;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFees() {
        return fees;
    }

    /**
     * 规费
     */
    public void setFees(java.math.BigDecimal fees) {
        this.fees = fees;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 占造价比例(%)(仅包括分部分项和单价措施)
     */
    public java.math.BigDecimal getCostRation() {
        return costRation;
    }

    /**
     * 占造价比例(%)(仅包括分部分项和单价措施)
     */
    public void setCostRation(java.math.BigDecimal costRation) {
        this.costRation = costRation;
    }
    /**
     * 工程规模(m²或m)
     */
    public java.math.BigDecimal getScale() {
        return scale;
    }

    /**
     * 工程规模(m²或m)
     */
    public void setScale(java.math.BigDecimal scale) {
        this.scale = scale;
    }
    /**
     * 单位造价(元/m²或元/m)
     */
    public java.math.BigDecimal getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价(元/m²或元/m)
     */
    public void setUnitCost(java.math.BigDecimal unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/record/bean/RecordquotasummarydetaillEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 限额设计汇总变更记录子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_quotasummarydetaill")
public class RecordquotasummarydetaillEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_mid")
    private java.lang.Long recordMid; // 主表id
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id（限额设计汇总子表）
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="unit_project_name")
    private java.lang.String unitProjectName; // 单位工程名称
    @TableField(value="project_cost")
    private java.math.BigDecimal projectCost; // 项目造价
    @TableField(value="labor_cost")
    private java.math.BigDecimal laborCost; // 人工费
    @TableField(value="material_cost")
    private java.math.BigDecimal materialCost; // 材料费
    @TableField(value="mechanical_cost")
    private java.math.BigDecimal mechanicalCost; // 机械费
    @TableField(value="management_cost")
    private java.math.BigDecimal managementCost; // 企业管理费
    @TableField(value="profit")
    private java.math.BigDecimal profit; // 利润
    @TableField(value="partial_item_total")
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    @TableField(value="among_thenl")
    private java.math.BigDecimal amongThenl; // 其中:施工垃圾场外晕和消纳费
    @TableField(value="measures_total")
    private java.math.BigDecimal measuresTotal; // 单方措施项目合计
    @TableField(value="other_items")
    private java.math.BigDecimal otherItems; // 其他项目
    @TableField(value="fees")
    private java.math.BigDecimal fees; // 规费
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="cost_ration")
    private java.math.BigDecimal costRation; // 占造价比例(%)(仅包括分部分项和单价措施)
    @TableField(value="scale")
    private java.math.BigDecimal scale; // 工程规模(m²或m)
    @TableField(value="unit_cost")
    private java.math.BigDecimal unitCost; // 单位造价(元/m²或元/m)
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getRecordMid() {
        return recordMid;
    }

    public void setRecordMid(Long recordMid) {
        this.recordMid = recordMid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 单位工程名称
     */
    public java.lang.String getUnitProjectName() {
        return unitProjectName;
    }

    /**
     * 单位工程名称
     */
    public void setUnitProjectName(java.lang.String unitProjectName) {
        this.unitProjectName = unitProjectName;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalCost() {
        return mechanicalCost;
    }

    /**
     * 机械费
     */
    public void setMechanicalCost(java.math.BigDecimal mechanicalCost) {
        this.mechanicalCost = mechanicalCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getManagementCost() {
        return managementCost;
    }

    /**
     * 企业管理费
     */
    public void setManagementCost(java.math.BigDecimal managementCost) {
        this.managementCost = managementCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其中:施工垃圾场外晕和消纳费
     */
    public java.math.BigDecimal getAmongThenl() {
        return amongThenl;
    }

    /**
     * 其中:施工垃圾场外晕和消纳费
     */
    public void setAmongThenl(java.math.BigDecimal amongThenl) {
        this.amongThenl = amongThenl;
    }
    /**
     * 单方措施项目合计
     */
    public java.math.BigDecimal getMeasuresTotal() {
        return measuresTotal;
    }

    /**
     * 单方措施项目合计
     */
    public void setMeasuresTotal(java.math.BigDecimal measuresTotal) {
        this.measuresTotal = measuresTotal;
    }
    /**
     * 其他项目
     */
    public java.math.BigDecimal getOtherItems() {
        return otherItems;
    }

    /**
     * 其他项目
     */
    public void setOtherItems(java.math.BigDecimal otherItems) {
        this.otherItems = otherItems;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFees() {
        return fees;
    }

    /**
     * 规费
     */
    public void setFees(java.math.BigDecimal fees) {
        this.fees = fees;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 占造价比例(%)(仅包括分部分项和单价措施)
     */
    public java.math.BigDecimal getCostRation() {
        return costRation;
    }

    /**
     * 占造价比例(%)(仅包括分部分项和单价措施)
     */
    public void setCostRation(java.math.BigDecimal costRation) {
        this.costRation = costRation;
    }
    /**
     * 工程规模(m²或m)
     */
    public java.math.BigDecimal getScale() {
        return scale;
    }

    /**
     * 工程规模(m²或m)
     */
    public void setScale(java.math.BigDecimal scale) {
        this.scale = scale;
    }
    /**
     * 单位造价(元/m²或元/m)
     */
    public java.math.BigDecimal getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价(元/m²或元/m)
     */
    public void setUnitCost(java.math.BigDecimal unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}
